//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
//
// $Id: ExN01PrimaryGeneratorAction.cc,v 1.6 2006/06/29 17:47:23 gunter Exp $
// GEANT4 tag $Name: geant4-08-01-patch-01 $
//

#include "CorsoPrimaryGeneratorAction.hh"

#include "G4Event.hh"
#include "G4ParticleGun.hh"
#include "G4ParticleTable.hh"
#include "G4ParticleDefinition.hh"
#include "globals.hh"

CorsoPrimaryGeneratorAction::CorsoPrimaryGeneratorAction()
{
  G4int n_particle = 1;
  particleGun = new G4ParticleGun(n_particle); // definiamo il numero di particelle da generare per evento
                                               // 1 nel nostro caso, 3 nel caso p0 gg

  G4ParticleTable* particleTable = G4ParticleTable::GetParticleTable();
  G4String particleName;
  particleGun->SetParticleDefinition(particleTable->FindParticle(particleName="e-")); // definisco il tipo di particella
  particleGun->SetParticleEnergy(1.0*GeV); // l'energia della particella
  particleGun->SetParticlePosition(G4ThreeVector(0.0,-10.0*cm, 0.0)); // generiamo il fascio sotto il blocco World
  particleGun->SetParticleMomentumDirection(G4ThreeVector(0.,1.,0.)); // direzione del fascio verso l'alto
}

CorsoPrimaryGeneratorAction::~CorsoPrimaryGeneratorAction()
{
  delete particleGun; // necessario, nel distruttore dobbiamo eliminare l'oggetto
}

void CorsoPrimaryGeneratorAction::GeneratePrimaries(G4Event* anEvent)
{
  // questa funzione genera il vertice primario (spiegare il formalismo di vertice e traccia)
  particleGun->GeneratePrimaryVertex(anEvent);
}


