//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
#include "CorsoRivelatore.hh" //possiamo inserirlo prima, perché abbiamo usato
                              // la pre-definizione

#include "G4Material.hh"  // Materiali
#include "G4Box.hh"       // Geometri Scatola
#include "G4Tubs.hh"
#include "G4LogicalVolume.hh" // Volumi logici
#include "G4ThreeVector.hh"
#include "G4PVPlacement.hh"
#include "globals.hh"

CorsoRivelatore::CorsoRivelatore() // costruttore, inizializziamo tutti gli oggetti
 :  pezzo_log(0), 
    pezzo_phys(0)
{;}

CorsoRivelatore::~CorsoRivelatore() // distruttore, non facciamo nulla
{
}

G4VPhysicalVolume* CorsoRivelatore::Construct() // Definizione del metodo Construct
{

  //------------------------------------------------------ materials

  G4double a;  // atomic mass
  G4double z;  // atomic number
  G4double density;

  //  G4Material* Ar = 
  //  new G4Material("ArgonGas", z= 18., a= 39.95*g/mole, density= 1.782*mg/cm3);

  //  G4Material* Al = 
  //  new G4Material("Aluminum", z= 13., a= 26.98*g/mole, density= 2.7*g/cm3);

  // Definiamo il materiale
  G4Material* Pb = 
  new G4Material("Lead", z= 82., a= 207.19*g/mole, density= 11.35*g/cm3);

  //------------------------------------------------------ volumes

  //------------------------------ experimental hall (world volume)
  //------------------------------ beam line along x axis

  G4double pezzo_x = 54.0*cm; // possiamo inserire un unità di misura -54 +54
  G4double pezzo_y = 10.0*cm;  // -10 + 10
  G4double pezzo_z = 10.0*cm;
  G4Box* pezzo_box
    = new G4Box("pezzo_box",pezzo_x,pezzo_y,pezzo_z); // creo una scatola
  pezzo_log = new G4LogicalVolume(pezzo_box, 
				  Pb,"pezzo_log",0,0,0); // creo un volume logico
  // lo posiziono, 0 rotazione no rotazione, altrimenti matrice di rotazione, G4ThrreVector(x,y,z) traslazione rispetto al volume madre, puntatore volume logico, nome,
  // puntatore volume madre (0 solo per World volume) nel nostro caso l'unico volume che abbiamo, numero di copia
  pezzo_phys = new G4PVPlacement(0,G4ThreeVector(),
				 pezzo_log,"pezzo",0,false,0); // posiziono il volume



  return pezzo_phys; // ritorno il mondo, ossia il pezzo
}

